@@ -30,6 +30,7 @@
 #include <KColorUtils>
 #include <KConfig>
 #include <KConfigGroup>
+#include <KIO/JobUiDelegateFactory>
 #include <KJob>
 #include <KJobWidgets>
 #include <KLocalizedString>
@@ -51,8 +52,6 @@
 
 #include <chrono>
 #include <cmath>
-#include <functional>
-#include <memory>
 
 #include "kfileplaceeditdialog.h"
 #include "kfileplacesmodel.h"
@@ -154,7 +153,7 @@ void KFilePlacesViewDelegate::paint(QPainter *painter, const QStyleOptionViewIte
     QApplication::style()->drawPrimitive(QStyle::PE_PanelItemViewItem, &opt, painter);
 
     QIcon actionIcon;
-    if (placesModel->isTeardownAllowed(index)) {
+    if (placesModel->isTeardownOverlayRecommended(index)) {
         actionIcon = QIcon::fromTheme(QStringLiteral("media-eject"));
     }
 
@@ -273,7 +272,7 @@ bool KFilePlacesViewDelegate::helpEvent(QHelpEvent *event, QAbstractItemView *vi
     if (event->type() == QHelpEvent::ToolTip) {
         if (pointIsTeardownAction(event->pos())) {
             if (auto *placesModel = qobject_cast<const KFilePlacesModel *>(index.model())) {
-                Q_ASSERT(placesModel->isTeardownAllowed(index));
+                Q_ASSERT(placesModel->isTeardownOverlayRecommended(index));
 
                 QString toolTipText;
 
@@ -398,7 +397,7 @@ bool KFilePlacesViewDelegate::pointIsTeardownAction(const QPoint &pos) const
         return false;
     }
 
-    if (!index.data(KFilePlacesModel::TeardownAllowedRole).toBool()) {
+    if (!index.data(KFilePlacesModel::TeardownOverlayRecommendedRole).toBool()) {
         return false;
     }
 
@@ -687,6 +686,7 @@ public:
     void itemAppearUpdate(qreal value);
     void itemDisappearUpdate(qreal value);
     void enableSmoothItemResizing();
+    void slotEmptyTrash();
 
     KFilePlacesView *const q;
 
@@ -755,7 +755,7 @@ KFilePlacesView::KFilePlacesView(QWidget *parent)
 
     d->m_watcher->m_scroller = QScroller::scroller(viewport());
     QScrollerProperties scrollerProp;
-    scrollerProp.setScrollMetric(QScrollerProperties::AcceleratingFlickMaximumTime, 0.2); //QTBUG-88249
+    scrollerProp.setScrollMetric(QScrollerProperties::AcceleratingFlickMaximumTime, 0.2); // QTBUG-88249
     d->m_watcher->m_scroller->setScrollerProperties(scrollerProp);
     d->m_watcher->m_scroller->grabGesture(viewport());
     connect(d->m_watcher->m_scroller, &QScroller::stateChanged, d->m_watcher, &KFilePlacesEventWatcher::qScrollerStateChanged);
@@ -1028,6 +1028,29 @@ void KFilePlacesViewPrivate::writeConfig()
     cg.sync();
 }
 
+void KFilePlacesViewPrivate::slotEmptyTrash()
+{
+    auto *parentWindow = q->window();
+    using AskIface = KIO::AskUserActionInterface;
+
+    if (!m_askUserHandler) {
+        m_askUserHandler.reset(new KIO::WidgetsAskUserActionHandler{});
+
+        auto slotAskResult = [parentWindow](bool allowDelete, const QList<QUrl> &, AskIface::DeletionType, QWidget *parent) {
+            if (parent != parentWindow || !allowDelete) {
+                return;
+            }
+
+            KIO::Job *job = KIO::emptyTrash();
+            job->setUiDelegate(KIO::createDefaultJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, parentWindow));
+        };
+
+        q->connect(m_askUserHandler.get(), &AskIface::askUserDeleteResult, q, slotAskResult);
+    }
+
+    m_askUserHandler->askUserDelete(QList<QUrl>{}, AskIface::EmptyTrash, AskIface::DefaultConfirmation, parentWindow);
+}
+
 void KFilePlacesView::contextMenuEvent(QContextMenuEvent *event)
 {
     KFilePlacesModel *placesModel = qobject_cast<KFilePlacesModel *>(model());
@@ -1191,28 +1214,8 @@ void KFilePlacesView::contextMenuEvent(QContextMenuEvent *event)
 
     if (result) {
         if (result == emptyTrash) {
-            auto *parentWindow = window();
+            d->slotEmptyTrash();
 
-            if (!d->m_askUserHandler) {
-                d->m_askUserHandler.reset(new KIO::WidgetsAskUserActionHandler{});
-
-                connect(d->m_askUserHandler.get(),
-                        &KIO::AskUserActionInterface::askUserDeleteResult,
-                        this,
-                        [parentWindow](bool allowDelete, const QList<QUrl> &, KIO::AskUserActionInterface::DeletionType, QWidget *parent) {
-                            if (parent != parentWindow || !allowDelete) {
-                                return;
-                            }
-
-                            KIO::Job *job = KIO::emptyTrash();
-                            job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, parentWindow));
-                        });
-            }
-
-            d->m_askUserHandler->askUserDelete(QList<QUrl>{},
-                                               KIO::AskUserActionInterface::EmptyTrash,
-                                               KIO::AskUserActionInterface::DefaultConfirmation,
-                                               parentWindow);
         } else if (result == eject) {
             placesModel->requestEject(index);
         } else if (result == mount) {
