@@ -1,30 +1,21 @@
-/* This file is part of the KDE project
-   Copyright (C) 1998-2009 David Faure <faure@kde.org>
-                 2003      Sven Leiber <s.leiber@web.de>
+/*
+    This file is part of the KDE project
+    SPDX-FileCopyrightText: 1998-2009 David Faure <faure@kde.org>
+    SPDX-FileCopyrightText: 2003 Sven Leiber <s.leiber@web.de>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 or at your option version 3.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only OR LGPL-3.0-only
 */
 
 #ifndef KNEWFILEMENU_H
 #define KNEWFILEMENU_H
 
-#include <QUrl>
-#include <kactionmenu.h>
 #include "kiofilewidgets_export.h"
 
+#include <KActionMenu>
+#include <QUrl>
+
+#include <memory>
+
 class KJob;
 
 class KActionCollection;
@@ -34,7 +25,7 @@ class KNewFileMenuPrivate;
  * @class KNewFileMenu knewfilemenu.h <KNewFileMenu>
  *
  * The 'Create New' submenu, for creating files using templates
- * (e.g. "new HTML file") and directories.
+ * (e.g.\ "new HTML file") and directories.
  *
  * The same instance can be used by both for the File menu and the RMB popup menu,
  * in a file manager. This is also used in the file dialog's RMB menu.
@@ -79,17 +70,21 @@ public:
      * of it don't need to parse the installed templates multiple times. Therefore
      * you can safely create and delete KNewMenu instances without a performance issue.
      */
-    virtual ~KNewFileMenu();
+    ~KNewFileMenu() override;
 
     /**
      * Returns the modality of dialogs
      */
     bool isModal() const;
 
+#if KIOFILEWIDGETS_ENABLE_DEPRECATED_SINCE(5, 97)
     /**
      * Returns the files that the popup is shown for
+     * @deprecated since 5.97, use KNewFileMenu::workingDirectory().
      */
+    KIOFILEWIDGETS_DEPRECATED_VERSION(5, 97, "Use KNewFileMenu::workingDirectory()")
     QList<QUrl> popupFiles() const;
+#endif
 
     /**
      * Sets the modality of dialogs created by KNewFile. Set to false if you do not want to block
@@ -103,42 +98,72 @@ public:
      */
     void setParentWidget(QWidget *parentWidget);
 
+#if KIOFILEWIDGETS_ENABLE_DEPRECATED_SINCE(5, 97)
     /**
      * Set the files the popup is shown for
      * Call this before showing up the menu
+     * @deprecated since 5.97, use KNewFileMenu::setWorkingDirectory(const QUrl &).
      */
+    KIOFILEWIDGETS_DEPRECATED_VERSION(5, 97, "Use KNewFileMenu::setWorkingDirectory(const QUrl &)")
     void setPopupFiles(const QList<QUrl> &files);
+#endif
+
+    /**
+     * Set the working directory.
+     * Files will be created relative to this directory.
+     * @since 5.97.
+     */
+    void setWorkingDirectory(const QUrl &directory);
+
+    /**
+     * Returns the working directory.
+     * Files will be created relative to this directory.
+     * @since 5.97.
+     */
+    QUrl workingDirectory() const;
 
 #if KIOFILEWIDGETS_ENABLE_DEPRECATED_SINCE(5, 0)
-    KIOFILEWIDGETS_DEPRECATED_VERSION(5, 0, "Use KNewFileMenu::setPopupFiles(const QList<QUrl> &)")
+    KIOFILEWIDGETS_DEPRECATED_VERSION(5, 0, "Use KNewFileMenu::setWorkingDirectory(const QUrl &)")
     void setPopupFiles(const QUrl &file)
     {
-        setPopupFiles(QList<QUrl>() << file);
+        setWorkingDirectory(file);
     }
 #endif
 
     /**
-     * Only show the files in a given set of mimetypes.
+     * Only show the files in a given set of MIME types.
      * This is useful in specialized applications (while file managers, on
-     * the other hand, want to show all mimetypes).
+     * the other hand, want to show all MIME types).
      */
     void setSupportedMimeTypes(const QStringList &mime);
 
+#if KIOFILEWIDGETS_ENABLE_DEPRECATED_SINCE(5, 97)
+    KIOFILEWIDGETS_DEPRECATED_VERSION(5, 97, "Calling this has no effect")
     /**
      * Set if the directory view currently shows dot files.
+     * @deprecated since 5.97. Calling this has no effect.
      */
     void setViewShowsHiddenFiles(bool b);
+#endif
 
     /**
-     * Returns the mimetypes set in supportedMimeTypes()
+     * Returns the MIME types set in supportedMimeTypes()
      */
     QStringList supportedMimeTypes() const;
 
+    /**
+     * Whether on not the dialog should emit `selectExistingDir` when trying to create an exist directory
+     *
+     * default: false
+     *
+     * @since 5.76
+     */
+    void setSelectDirWhenAlreadyExist(bool b);
+
 public Q_SLOTS:
     /**
      * Checks if updating the list is necessary
      * IMPORTANT : Call this in the slot for aboutToShow.
-     * And while you're there, you probably want to call setViewShowsHiddenFiles ;)
      */
     void checkUpToDate();
 
@@ -147,7 +172,7 @@ public Q_SLOTS:
      * a popupmenu. This is useful to make sure that creating a directory with
      * a key shortcut (e.g. F10) triggers the exact same code as when using
      * the New menu.
-     * Requirements: call setPopupFiles first, and keep this KNewFileMenu instance
+     * Requirements: since 5.97 call setWorkingDirectory first (for older releases call setPopupFiles first), and keep this KNewFileMenu instance
      * alive (the mkdir is async).
      */
     void createDirectory();
@@ -157,7 +182,7 @@ public Q_SLOTS:
      * a popupmenu. This is useful to make sure that creating a directory with
      * a key shortcut (e.g. Shift-F10) triggers the exact same code as when using
      * the New menu.
-     * Requirements: call setPopupFiles first, and keep this KNewFileMenu instance
+     * Requirements: since 5.97 call setWorkingDirectory first (for older releases call setPopupFiles first), and keep this KNewFileMenu instance
      * alive (the copy is async).
      * @since 5.53
      */
@@ -174,6 +199,16 @@ Q_SIGNALS:
      */
     void directoryCreated(const QUrl &url);
 
+    /**
+     * Emitted when trying to create a new directory that has the same name as
+     * an existing one, so that KDirOperator can select the existing item in
+     * the view (in case the user wants to use that directory instead of creating
+     * a new one).
+     *
+     * @since 5.76
+     */
+    void selectExistingDir(const QUrl &url);
+
 protected Q_SLOTS:
 
     /**
@@ -184,21 +219,8 @@ protected Q_SLOTS:
     virtual void slotResult(KJob *job);
 
 private:
-    Q_PRIVATE_SLOT(d, void _k_slotAbortDialog())
-    Q_PRIVATE_SLOT(d, void _k_slotActionTriggered(QAction *))
-    Q_PRIVATE_SLOT(d, void _k_slotCreateDirectory(bool writeHiddenDir = false))
-    Q_PRIVATE_SLOT(d, void _k_slotCreateHiddenDirectory())
-    Q_PRIVATE_SLOT(d, void _k_slotFillTemplates())
-    Q_PRIVATE_SLOT(d, void _k_slotOtherDesktopFile())
-    Q_PRIVATE_SLOT(d, void _k_slotOtherDesktopFileClosed())
-    Q_PRIVATE_SLOT(d, void _k_slotRealFileOrDir())
-    Q_PRIVATE_SLOT(d, void _k_slotTextChanged(const QString))
-    Q_PRIVATE_SLOT(d, void _k_slotSymLink())
-    Q_PRIVATE_SLOT(d, void _k_slotUrlDesktopFile())
-
     friend class KNewFileMenuPrivate;
-    KNewFileMenuPrivate *const d;
-
+    std::unique_ptr<KNewFileMenuPrivate> const d;
 };
 
 #endif
