@@ -36,10 +36,76 @@ public:
     // Creates a KSslInfoDialog or falls back to a generic Information dialog
     void sslMessageBox(const QString &text, const KIO::MetaData &metaData, QWidget *parent);
 
+    bool gotPersistentUserReply(KIO::AskUserActionInterface::MessageDialogType type, const KConfigGroup &cg, const QString &dontAskAgainName);
+    void savePersistentUserReply(KIO::AskUserActionInterface::MessageDialogType type, KConfigGroup &cg, const QString &dontAskAgainName, int result);
+
     WidgetsAskUserActionHandler *const q;
     QWidget *m_parentWidget = nullptr;
 };
 
+bool KIO::WidgetsAskUserActionHandlerPrivate::gotPersistentUserReply(KIO::AskUserActionInterface::MessageDialogType type,
+                                                                     const KConfigGroup &cg,
+                                                                     const QString &dontAskAgainName)
+{
+    // storage values matching the logic of FrameworkIntegration's KMessageBoxDontAskAgainConfigStorage
+    switch (type) {
+    case KIO::AskUserActionInterface::QuestionYesNo:
+    case KIO::AskUserActionInterface::QuestionYesNoCancel:
+    case KIO::AskUserActionInterface::WarningYesNo:
+    case KIO::AskUserActionInterface::WarningYesNoCancel: {
+        // storage holds "true" if persistent reply is "Yes", "false" for persistent "No",
+        // otherwise no persistent reply is present
+        const QString value = cg.readEntry(dontAskAgainName, QString());
+        if ((value.compare(QLatin1String("yes"), Qt::CaseInsensitive) == 0) || (value.compare(QLatin1String("true"), Qt::CaseInsensitive) == 0)) {
+            Q_EMIT q->messageBoxResult(KIO::SlaveBase::Yes);
+            return true;
+        }
+        if ((value.compare(QLatin1String("no"), Qt::CaseInsensitive) == 0) || (value.compare(QLatin1String("false"), Qt::CaseInsensitive) == 0)) {
+            Q_EMIT q->messageBoxResult(KIO::SlaveBase::No);
+            return true;
+        }
+        break;
+    }
+    case KIO::AskUserActionInterface::WarningContinueCancel: {
+        // storage holds "false" if persistent reply is "Continue"
+        // otherwise no persistent reply is present
+        const bool value = cg.readEntry(dontAskAgainName, true);
+        if (value == false) {
+            Q_EMIT q->messageBoxResult(KIO::SlaveBase::Continue);
+            return true;
+        }
+        break;
+    }
+    default:
+        break;
+    }
+
+    return false;
+}
+
+void KIO::WidgetsAskUserActionHandlerPrivate::savePersistentUserReply(KIO::AskUserActionInterface::MessageDialogType type,
+                                                                      KConfigGroup &cg,
+                                                                      const QString &dontAskAgainName,
+                                                                      int result)
+{
+    // see gotPersistentUserReply for values stored and why
+    switch (type) {
+    case KIO::AskUserActionInterface::QuestionYesNo:
+    case KIO::AskUserActionInterface::QuestionYesNoCancel:
+    case KIO::AskUserActionInterface::WarningYesNo:
+    case KIO::AskUserActionInterface::WarningYesNoCancel:
+        cg.writeEntry(dontAskAgainName, result == KIO::SlaveBase::Yes);
+        cg.sync();
+        break;
+    case KIO::AskUserActionInterface::WarningContinueCancel:
+        cg.writeEntry(dontAskAgainName, false);
+        cg.sync();
+        break;
+    default:
+        break;
+    }
+}
+
 KIO::WidgetsAskUserActionHandler::WidgetsAskUserActionHandler(QObject *parent)
     : KIO::AskUserActionInterface(parent)
     , d(new WidgetsAskUserActionHandlerPrivate(this))
@@ -51,7 +117,7 @@ KIO::WidgetsAskUserActionHandler::~WidgetsAskUserActionHandler()
 }
 
 void KIO::WidgetsAskUserActionHandler::askUserRename(KJob *job,
-                                                     const QString &caption,
+                                                     const QString &title,
                                                      const QUrl &src,
                                                      const QUrl &dest,
                                                      KIO::RenameDialog_Options options,
@@ -76,7 +142,7 @@ void KIO::WidgetsAskUserActionHandler::askUserRename(KJob *job,
         parentWidget = qApp->activeWindow();
     }
 
-    auto *dlg = new KIO::RenameDialog(parentWidget, caption, src, dest, options, sizeSrc, sizeDest, ctimeSrc, ctimeDest, mtimeSrc, mtimeDest);
+    auto *dlg = new KIO::RenameDialog(parentWidget, title, src, dest, options, sizeSrc, sizeDest, ctimeSrc, ctimeDest, mtimeSrc, mtimeDest);
 
     dlg->setAttribute(Qt::WA_DeleteOnClose);
     dlg->setWindowModality(Qt::WindowModal);
@@ -171,7 +237,7 @@ void KIO::WidgetsAskUserActionHandler::askUserDelete(const QList<QUrl> &urls, De
     KMessageDialog::Type dialogType = KMessageDialog::QuestionYesNo;
     KGuiItem acceptButton;
     QString text;
-    QString caption = i18n("Delete Permanently");
+    QString title = i18n("Delete Permanently");
 
     switch (deletionType) {
     case Delete: {
@@ -203,8 +269,8 @@ void KIO::WidgetsAskUserActionHandler::askUserDelete(const QList<QUrl> &urls, De
             text =
                 xi18ncp("@info", "Do you really want to move this %1 item to the Trash?", "Do you really want to move these %1 items to the Trash?", urlCount);
         }
-        caption = i18n("Move to Trash");
-        acceptButton = KGuiItem(caption, QStringLiteral("user-trash"));
+        title = i18n("Move to Trash");
+        acceptButton = KGuiItem(title, QStringLiteral("user-trash"));
         break;
     }
     default:
@@ -214,7 +280,7 @@ void KIO::WidgetsAskUserActionHandler::askUserDelete(const QList<QUrl> &urls, De
     KMessageDialog *dlg = new KMessageDialog(dialogType, text, parent);
 
     dlg->setAttribute(Qt::WA_DeleteOnClose);
-    dlg->setCaption(caption);
+    dlg->setCaption(title);
     dlg->setIcon(QIcon{});
     dlg->setButtons(acceptButton, KStandardGuiItem::cancel());
     if (urlCount > 1) {
@@ -242,7 +308,7 @@ void KIO::WidgetsAskUserActionHandler::askUserDelete(const QList<QUrl> &urls, De
 
 void KIO::WidgetsAskUserActionHandler::requestUserMessageBox(MessageDialogType type,
                                                              const QString &text,
-                                                             const QString &caption,
+                                                             const QString &title,
                                                              const QString &buttonYes,
                                                              const QString &buttonNo,
                                                              const QString &iconYes,
@@ -253,10 +319,8 @@ void KIO::WidgetsAskUserActionHandler::requestUserMessageBox(MessageDialogType t
                                                              QWidget *parent)
 {
     KSharedConfigPtr reqMsgConfig = KSharedConfig::openConfig(QStringLiteral("kioslaverc"));
-    const bool ask = reqMsgConfig->group("Notification Messages").readEntry(dontAskAgainName, true);
 
-    if (!ask) {
-        Q_EMIT messageBoxResult(type == WarningContinueCancel ? KIO::SlaveBase::Continue : KIO::SlaveBase::Yes);
+    if (d->gotPersistentUserReply(type, reqMsgConfig->group("Notification Messages"), dontAskAgainName)) {
         return;
     }
 
@@ -291,10 +355,19 @@ void KIO::WidgetsAskUserActionHandler::requestUserMessageBox(MessageDialogType t
         dlgType = KMessageDialog::Information;
         dontAskAgainText = i18nc("@option:check", "Do not show this message again");
         break;
+#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 97)
     case Sorry:
+#if KWIDGETSADDONS_BUILD_DEPRECATED_SINCE(5, 97)
+        QT_WARNING_PUSH
+        QT_WARNING_DISABLE_DEPRECATED
         dlgType = KMessageDialog::Sorry;
+        QT_WARNING_POP
         dontAskAgainText = QString{}; // No dontAskAgain checkbox
         break;
+#else
+#error "Cannot build KIOCore with KIO::AskUserActionInterface::Sorry with KMessageDialog::Sorry disabled"
+#endif
+#endif
     case Error:
         dlgType = KMessageDialog::Error;
         dontAskAgainText = QString{}; // No dontAskAgain checkbox
@@ -307,14 +380,14 @@ void KIO::WidgetsAskUserActionHandler::requestUserMessageBox(MessageDialogType t
     auto *dialog = new KMessageDialog(dlgType, text, parent);
 
     dialog->setAttribute(Qt::WA_DeleteOnClose);
-    dialog->setCaption(caption);
+    dialog->setCaption(title);
     dialog->setIcon(QIcon{});
     // If a button has empty text, KMessageDialog will replace that button
     // with a suitable KStandardGuiItem
     dialog->setButtons(acceptButton, rejectButton);
     dialog->setDetails(details);
     dialog->setDontAskAgainText(dontAskAgainText);
-    dialog->setDontAskAgainChecked(!ask);
+    dialog->setDontAskAgainChecked(false);
     dialog->setOpenExternalLinks(true); // Allow opening external links in the text labels
 
     connect(dialog, &QDialog::finished, this, [=](const int result) {
@@ -343,10 +416,9 @@ void KIO::WidgetsAskUserActionHandler::requestUserMessageBox(MessageDialogType t
 
         Q_EMIT messageBoxResult(btnCode);
 
-        if (result != QDialogButtonBox::Cancel) {
+        if ((result != QDialogButtonBox::Cancel) && dialog->isDontAskAgainChecked()) {
             KConfigGroup cg = reqMsgConfig->group("Notification Messages");
-            cg.writeEntry(dontAskAgainName, !dialog->isDontAskAgainChecked());
-            cg.sync();
+            d->savePersistentUserReply(type, cg, dontAskAgainName, result);
         }
     });
 
